@@ -13,6 +13,9 @@ LOGGER = logging.getLogger('InaSAFE')
 class FloodBuildingImpactFunction(FunctionProvider):
     """Inundation impact on building data
 
+    :author Ole Nielsen, Kristy van Putten
+    # this rating below is only for testing a function, not the real one
+    :rating 0
     :param requires category=='hazard' and \
                     subcategory in ['flood', 'tsunami']
 
@@ -21,8 +24,24 @@ class FloodBuildingImpactFunction(FunctionProvider):
                     layertype=='vector'
     """
 
+    # Function documentation
     target_field = 'INUNDATED'
     title = tr('Be flooded')
+    synopsis = tr('To assess the impacts of inundation on building footprints '
+        'originating from OpenStreetMap (OSM).')
+    actions = tr('Provide details about where critical response areas are')
+    # citations must be a list
+    citations = [tr('Hutchings, Field & Parks. Assessment of Flood impacts on '
+        'buildings. Impact. Vol 66(2). 2012')]
+    detailed_description = tr('This is an area for free form text where a'
+        'detailed description of the methodology used is given.')
+    permissible_hazard_input = tr('A raster layer where each cell represents '
+        'flood depth, or a vector polygon layer where each polygon represents '
+        'an inundated area. Optionally the user may nominate an attribute in '
+        'the polygon layer that represents inundation depth.')
+    permissible_exposure_input = tr('vector polygon layer extracted from OSM '
+        'where each polygon represents the footprint of a building.')
+    limitation = tr('Lorem ipsum limitation')
 
     def run(self, layers):
         """Flood impact to buildings (e.g. from Open Street Map)
